@@ -99,6 +99,10 @@ class Camera(BaseCamera):
 
         # print("i... staticmethod frames @ real -  enterred; target_frame==", target_frame)
         senh = Stream_Enhancer()
+        try:
+            senh.zmqtarget = config.CONFIG['imagezmq']
+        except:
+            print("!... neet to update config for imagezmq")
 
         # === I must have these GLOBAL and PREDEFINED HERE <= web.py
         # --------------------------------  control
