@@ -15,6 +15,15 @@ import datetime as dt
 from flashcam.version import __version__
 import os
 
+
+# run this program on each RPi to send a labelled image stream
+import socket
+import time
+from imutils.video import VideoStream
+import imagezmq
+import threading
+
+
 class Stream_Enhancer:
     """
     definitions of positions on the frame
@@ -82,6 +91,11 @@ class Stream_Enhancer:
     BGFILE = os.path.expanduser('~/.config/flashcam/background.jpg')
     FGFILE = os.path.expanduser('~/.config/flashcam/foreground.jpg')
 
+    zmqrpi_name = socket.gethostname()
+    zmqtarget = None
+    zmqsender = None
+    zmqlast = dt.datetime.now()
+
 
     def RC_COLOR(self,row,col):
         if not self.frame_ok: return  # B  G R
@@ -790,12 +804,17 @@ class Stream_Enhancer:
                 filename = dt.datetime.now().strftime("%Y%m%d_%H%M%S")
                 me = socket.gethostname()
                 filename = f"{me}{name}_{filename}.avi"
-                filename = os.path.expanduser("~/"+filename)
+                filename = os.path.expanduser("~/DATA/"+filename)
                 print(filename)
                 print(filename)
                 print(filename)
                 print(filename)
 
+                print("!... getting zmq sender:", self.zmqtarget)
+                if not self.zmqtarget is None:
+                    self.zmqsender = imagezmq.ImageSender(connect_to=f'tcp://{self.zmqtarget}:5555')
+                    print("!... got it", self.zmqsender)
+
                 fourcc = cv2.VideoWriter_fourcc(*'XVID')
                 self.aviout = cv2.VideoWriter( filename , fourcc , 25.0, (640,480))
                 self.aviopened = True
@@ -805,7 +824,7 @@ class Stream_Enhancer:
                 filename = dt.datetime.now().strftime("%Y%m%d_%H%M%S")
                 me = socket.gethostname()
                 filename = f"{me}{name}_{filename}.avi"
-                filename = os.path.expanduser("~/"+filename)
+                filename = os.path.expanduser("~/DATA/"+filename)
                 print(filename)
                 print(filename)
                 print(filename)
@@ -817,13 +836,26 @@ class Stream_Enhancer:
                 self.aviout = cv2.VideoWriter( filename , fourcc , 25.0, (640,480))
 
             self.aviout.write(self.frame)
+
+
+            if  (self.zmqsender is None) and (not self.zmqtarget is None):
+                self.zmqsender = imagezmq.ImageSender(connect_to=f'tcp://{self.zmqtarget}:5555')
+
+            if not self.zmqsender is None:
+                zmqnow = dt.datetime.now()
+                if (zmqnow-self.zmqlast).total_seconds()>1.5:
+                    x = threading.Thread(target=self.zmqsender.send_image, args=(self.zmqrpi_name, self.frame))
+                    x.start()
+                    #self.zmqsender.send_image(self.zmqrpi_name, self.frame)
+                    self.zmqlast=zmqnow
+                    print(f"i... zmq is sent to {self.zmqtarget}")
         # -------------- timelapse if seconds>0:
         elif seconds>0:
             if not self.aviopened_laps:
                 filename = dt.datetime.now().strftime("%Y%m%d_%H%M%S")
                 me = socket.gethostname()
                 filename = f"{me}_laps{seconds:04d}_{filename}.avi"
-                filename = os.path.expanduser("~/"+filename)
+                filename = os.path.expanduser("~/DATA/"+filename)
                 print(filename)
                 print(filename)
                 print(filename)
