@@ -41,7 +41,14 @@ class V4L2_Control:
         self.min = min
         self.max = max
         self.step = step
-        self.default = default
+
+
+        # the cheap sonix camera problem
+        if (default>max) or (default<min):
+            self.default = self.min
+        else:
+            self.default = default
+
         self.value = value
         self.flags = flags
 
